"""Top-level package for BleBox Python UniAPI."""

__author__ = """Gadget Mobile"""
__email__ = "the_gadget_mobile@yahoo.com"
__version__ = '1.1.0'
